abacusai.feature_mapping — AbacusAI documentation

# `abacusai.feature_mapping`

## Module Contents

### Classes

`FeatureMapping` | A description of the data use for a feature

class abacusai.feature_mapping.FeatureMapping(client, featureMapping=None, featureName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A description of the data use for a feature

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureMapping (str) – The mapping of the feature. The possible values will be based on the project’s use-case. See the (Use Case Documentation)[https://api.abacus.ai/app/help/useCases] for more details.

    - featureName (str) – The unique name of the feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict